@@ -64,7 +64,7 @@ class InstanceResolver(CommonResolver):
                     }
                     logger.debug("Added instance: %s: %r", instance_id, items[instance_id])
                 except (KeyError, ValueError):
-                    logger.warning("SSM inventory entity not recognised: %s", entity)
+                    logger.debug("SSM inventory entity not recognised: %s", entity)
                     continue
 
         # Add attributes from EC2
@@ -107,7 +107,7 @@ class InstanceResolver(CommonResolver):
                     raise
                 message = ex.response.get('Error', {}).get('Message', '')
                 if not message.startswith("The instance ID") or not message.endswith("not exist"):
-                    logger.warning("Unexpected InvalidInstanceID.NotFound message:", message)
+                    logger.warning("Unexpected InvalidInstanceID.NotFound message: %s", message)
                 # Try to extract instace ids ...
                 remove_instance_ids = re.findall('i-[0-9a-f]+', message)
                 logger.debug("Removing non-existent InstanceIds: %s", remove_instance_ids)
@@ -142,7 +142,7 @@ class InstanceResolver(CommonResolver):
 
     def resolve_instance(self, instance):
         # Is it a valid Instance ID?
-        if re.match('^i-[a-f0-9]+$', instance):
+        if re.match('^m?i-[a-f0-9]+$', instance):
             return instance
 
         # It is not - find it in the list
@@ -172,6 +172,7 @@ class ContainerResolver(CommonResolver):
         # Create boto3 clients from session
         self.ecs_client = self.session.client('ecs')
 
+        self.args = args
         self.containers = []
         self._tasks = {}
 
@@ -201,6 +202,14 @@ class ContainerResolver(CommonResolver):
         for page in paginator.paginate():
             clusters.extend(page['clusterArns'])
 
+        if self.args.cluster:
+            filtered_clusters = []
+            for cluster in clusters:
+                if ((self.args.cluster.startswith('arn:') and cluster == self.args.cluster) or cluster.endswith(f"/{self.args.cluster}")):
+                    filtered_clusters.append(cluster)
+                    break
+            clusters = filtered_clusters
+
         if not clusters:
             logger.warning("No ECS Clusters found.")
             return []
@@ -267,7 +276,7 @@ class ContainerResolver(CommonResolver):
             self.print_containers(candidates)
             return candidates[0]
         else:
-            logger.warning("Found %d instances for: %s", len(containers), keyword)
+            logger.warning("Found %d instances for: %s", len(candidates), keyword)
             logger.warning("Use Container IP or Task ID to connect to a specific one")
             self.print_containers(candidates)
             quit(1)
